==> estateplat-common-1.2.3-20181108.110720-210-sources.jar: cn/gtmap/estateplat/model/server/core/BdcFwfsss.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * 发票编号
 *
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2016/5/28
 * @descriptio
 */
@Table(name = "bdc_fwfsss")
public class BdcFwfsss implements InsertVo, Serializable {
    @Id
    private String fwfsssid;//主键
    private String ghyt;//规划用途
    private Double jyjg;//房地产交易价格
    private String dw;//单位
    private Double jzmj;//建筑面积
    private Double tnjzmj;//套内建筑面积
    private String dwdm;
    private String bz;
    private Double cg;   // 层高
    private String proid;
    private String bdcdyid;
    private String fwzl;  // 坐落
    private Double ftjzmj;
    private String bdcdyh;

    private Double fttdmj;//分摊土地面积

    private String fwbm;  // 房屋编码

    private String zfbdcdyh;//主房不动产单元号

    private String wiid;//工作流id

    private String yqlid;//原权利Id
    private String yproid;//原项目Id

    private Short jrfzmj=0; //计入发证面积

    public String getFwfsssid() {
        return fwfsssid;
    }

    public void setFwfsssid(String fwfsssid) {
        this.fwfsssid = fwfsssid;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public Double getJyjg() {
        return jyjg;
    }

    public void setJyjg(Double jyjg) {
        this.jyjg = jyjg;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Double getCg() {
        return cg;
    }

    public void setCg(Double cg) {
        this.cg = cg;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public Double getTnjzmj() {
        return tnjzmj;
    }

    public void setTnjzmj(Double tnjzmj) {
        this.tnjzmj = tnjzmj;
    }

    public Double getFtjzmj() {
        return ftjzmj;
    }

    public void setFtjzmj(Double ftjzmj) {
        this.ftjzmj = ftjzmj;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public String getZfbdcdyh() {
        return zfbdcdyh;
    }

    public void setZfbdcdyh(String zfbdcdyh) {
        this.zfbdcdyh = zfbdcdyh;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getYqlid() {
        return yqlid;
    }

    public void setYqlid(String yqlid) {
        this.yqlid = yqlid;
    }

    public String getYproid() {
        return yproid;
    }

    public void setYproid(String yproid) {
        this.yproid = yproid;
    }

    public Short getJrfzmj() {
        return jrfzmj;
    }

    public void setJrfzmj(Short jrfzmj) {
        this.jrfzmj = jrfzmj;
    }
}

==> estateplat-common-1.2.4-20200715.063357-391-sources.jar: cn/gtmap/estateplat/model/server/core/BdcFwfsss.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;
/**
 * 发票编号
 *
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2016/5/28
 * @descriptio
 */
@Table(name = "bdc_fwfsss")
public class BdcFwfsss implements InsertVo, Serializable {
    @Id
    private String fwfsssid;//主键
    private String ghyt;//规划用途
    private Double jyjg;//房地产交易价格
    private String dw;//单位
    private Double jzmj;//建筑面积
    private Double tnjzmj;//套内建筑面积
    private String dwdm;
    private String bz;
    private Double cg;   // 层高
    private String proid;
    private String bdcdyid;
    private String fwzl;  // 坐落
    private Double ftjzmj;
    private String bdcdyh;

    private Double fttdmj;//分摊土地面积

    private String fwbm;  // 房屋编码

    private String zfbdcdyh;//主房不动产单元号

    private String wiid;//工作流id

    private String yqlid;//原权利Id
    private String yproid;//原项目Id

    private Short jrfzmj=0; //计入发证面积
    private String szc; //所在层
    private String cwh; //车位号
    private Date sssyksqx; //设施使用开始期限
    private Date sssyjsqx; //设施使用结束期限
    private Integer sfdy; //是否抵押

    public String getFwfsssid() {
        return fwfsssid;
    }

    public void setFwfsssid(String fwfsssid) {
        this.fwfsssid = fwfsssid;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public Double getJyjg() {
        return jyjg;
    }

    public void setJyjg(Double jyjg) {
        this.jyjg = jyjg;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Double getCg() {
        return cg;
    }

    public void setCg(Double cg) {
        this.cg = cg;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public Double getTnjzmj() {
        return tnjzmj;
    }

    public void setTnjzmj(Double tnjzmj) {
        this.tnjzmj = tnjzmj;
    }

    public Double getFtjzmj() {
        return ftjzmj;
    }

    public void setFtjzmj(Double ftjzmj) {
        this.ftjzmj = ftjzmj;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public String getZfbdcdyh() {
        return zfbdcdyh;
    }

    public void setZfbdcdyh(String zfbdcdyh) {
        this.zfbdcdyh = zfbdcdyh;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getYqlid() {
        return yqlid;
    }

    public void setYqlid(String yqlid) {
        this.yqlid = yqlid;
    }

    public String getYproid() {
        return yproid;
    }

    public void setYproid(String yproid) {
        this.yproid = yproid;
    }

    public Short getJrfzmj() {
        return jrfzmj;
    }

    public void setJrfzmj(Short jrfzmj) {
        this.jrfzmj = jrfzmj;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getCwh() {
        return cwh;
    }

    public void setCwh(String cwh) {
        this.cwh = cwh;
    }

    public Date getSssyksqx() {
        return sssyksqx;
    }

    public void setSssyksqx(Date sssyksqx) {
        this.sssyksqx = sssyksqx;
    }

    public Date getSssyjsqx() {
        return sssyjsqx;
    }

    public void setSssyjsqx(Date sssyjsqx) {
        this.sssyjsqx = sssyjsqx;
    }
}
